@@ -2,6 +2,7 @@ use super::{node::NodeProvider, Provider};
 use crate::nixpacks::{
     app::App,
     environment::{Environment, EnvironmentVariables},
+    nix::pkg::Pkg,
     plan::{
         phase::{Phase, StartPhase},
         BuildPlan,
@@ -91,6 +92,13 @@ impl RubyProvider {
         install.add_path(format!("/usr/local/rvm/gems/{}/bin", ruby_version));
         install.add_path(format!("/usr/local/rvm/gems/{}@global/bin", ruby_version));
 
+        if self.uses_gem_dep(app, "execjs") {
+            install.add_nix_pkgs(&[Pkg::new("nodejs")]);
+        }
+        if self.uses_gem_dep(app, "rmagick") {
+            install.add_apt_pkgs(vec![String::from("libmagickwand-dev")]);
+            install.add_nix_pkgs(&[Pkg::new("imagemagick")]);
+        }
         if self.uses_gem_dep(app, "charlock_holmes") {
             install.add_apt_pkgs(vec![String::from("libicu-dev")]);
         }
